@@ -1,5 +1,5 @@
 <?php
-/* $Id: spanish-iso-8859-15.inc.php 11113 2008-02-09 16:09:54Z lem9 $ */
+/* $Id: spanish-iso-8859-15.inc.php 11212 2008-04-23 16:28:20Z lem9 $ */
 
 $charset = 'iso-8859-15';
 $text_dir = 'ltr';
@@ -890,6 +890,7 @@ $strStructure = 'Estructura';
 $strStructureForView = 'Estructura para la vista';
 $strSubmit = 'Enviar';
 $strSuccess = 'Su consulta se ejecut con xito';
+$strSuhosin = 'El servidor est utilizando Suhosin. Por favor, refirase a %sdocumentation%s para posibles ajustes.';
 $strSum = 'Nmero de filas';
 $strSwedish = 'Sueco';
 $strSwitchToDatabase = 'Seleccionar la base de datos copiada';
@@ -1022,5 +1023,4 @@ $strYes = 'S';
 $strZeroRemovesTheLimit = 'Nota: si cambia los parmetros de estas opciones a 0 (cero), remueve el lmite.';
 $strZip = '"comprimido con zip"';
 
-$strSuhosin = 'Server running with Suhosin. Please refer to %sdocumentation%s for possible issues.';  //to translate
 ?>
